@@ -2,14 +2,13 @@ from .bucket import Bucket, BucketSegment, BucketType, CategoryMeasureBucket, Ca
 	CategorySegmentValue, EnumMeasureBucket, MeasureBucket, NumericSegmentsHolder, NumericSegmentValue, \
 	NumericValueBucket, NumericValueMeasureBucket, NumericValueSegment, OtherCategorySegmentValue, \
 	RangeBucketValueIncluding
-from .indicator import Indicator, IndicatorAggregateArithmetic, IndicatorMeasure, RelevantIndicator, \
+from .indicator import Indicator, IndicatorAggregateArithmetic, IndicatorBaseOn, RelevantIndicator, \
 	RelevantIndicatorType
 from .inspection import Inspection, InspectionAmPmRange, InspectionDayKindRange, InspectionDayOfMonthRange, \
 	InspectionDayOfWeekRange, InspectionHalfMonthRange, InspectionHalfWeekRange, InspectionHalfYearRange, \
 	InspectionHourKindRange, InspectionHourRange, InspectionMonthRange, InspectionQuarterRange, \
 	InspectionTenDaysRange, InspectionTimeRange, InspectionTimeRangeType, InspectionWeekOfMonthRange, \
-	InspectionWeekOfYearRange, \
-	InspectionYearRange, InspectMeasureOn
+	InspectionWeekOfYearRange, InspectionYearRange, InspectMeasureOn
 from .measure_method import MeasureMethod
 from .navigation import MANUAL_COMPUTE_NAVIGATION_INDICATOR_ID, ManualComputeNavigationIndicator, Navigation, \
 	NavigationIndicator, NavigationIndicatorCriteria, NavigationIndicatorCriteriaOnBucket, \
